# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.common.v1.config.Flag import Flag  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.config.KVPair import KVPair  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.config.Message import Message  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501

class ApiResponseMetadata(object):

    """The metadata associated with an API response. This value is always present and minimally contains the self-link for the API request that produced this response. It also contains pagination data for the paginated requests. 

    :param flags: (:attr:`flags`) An array of flags that may indicate the status of the response. For example, a flag with the name 'isPaginated' and value 'false', indicates that the response is not paginated. 
    :type flags: 
    
    
    :param links: (:attr:`links`) An array of HATEOAS style links for the response that may also include pagination links for list operations. 
    :type links: 
    
    
    :param total_available_results: (:attr:`total_available_results`) The total number of entities that are available on the server for this type. 
    :type total_available_results: 
    
    
    :param messages: (:attr:`messages`) Information, Warning or Error messages that might provide additional contextual information related to the operation. 
    :type messages: 
    
    
    :param extra_info: (:attr:`extra_info`) An array of entity-specific metadata 
    :type extra_info: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'flags': 'list[common.v1.config.Flag]',
        'links': 'list[common.v1.response.ApiLink]',
        'total_available_results': 'int',
        'messages': 'list[common.v1.config.Message]',
        'extra_info': 'list[common.v1.config.KVPair]',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'flags': 'flags',
        'links': 'links',
        'total_available_results': 'totalAvailableResults',
        'messages': 'messages',
        'extra_info': 'extraInfo',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, flags=None, links=None, total_available_results=None, messages=None, extra_info=None, *args, **kwargs):  # noqa: E501
        self.__flags = None
        self.__links = None
        self.__total_available_results = None
        self.__messages = None
        self.__extra_info = None
        self.discriminator = None
        if flags is not None:
            self.__flags = flags
        if links is not None:
            self.__links = links
        if total_available_results is not None:
            self.__total_available_results = total_available_results
        if messages is not None:
            self.__messages = messages
        if extra_info is not None:
            self.__extra_info = extra_info
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'common.v1.response.ApiResponseMetadata'

    def _initialize_object_version(self):
        return 'v1.r0'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def flags(self):
        """
        An array of flags that may indicate the status of the response. For example, a flag with the name 'isPaginated' and value 'false', indicates that the response is not paginated. 

        :type:
             list[ :class:`~ntnx_security_py_client.models.common.v1.config.Flag` ]
        """  # noqa: E501
        return self.__flags

    @flags.setter
    def flags(self, flags):

        self.__flags = flags

    @property
    def links(self):
        """
        An array of HATEOAS style links for the response that may also include pagination links for list operations. 

        :type:
             list[ :class:`~ntnx_security_py_client.models.common.v1.response.ApiLink` ]
        """  # noqa: E501
        return self.__links

    @links.setter
    def links(self, links):

        self.__links = links

    @property
    def total_available_results(self):
        """
        The total number of entities that are available on the server for this type. 

        :type:
                :class:`~int`
        """  # noqa: E501
        return self.__total_available_results

    @total_available_results.setter
    def total_available_results(self, total_available_results):

        self.__total_available_results = total_available_results

    @property
    def messages(self):
        """
        Information, Warning or Error messages that might provide additional contextual information related to the operation. 

        :type:
             list[ :class:`~ntnx_security_py_client.models.common.v1.config.Message` ]
        """  # noqa: E501
        return self.__messages

    @messages.setter
    def messages(self, messages):

        self.__messages = messages

    @property
    def extra_info(self):
        """
        An array of entity-specific metadata 

        :type:
             list[ :class:`~ntnx_security_py_client.models.common.v1.config.KVPair` ]
        """  # noqa: E501
        return self.__extra_info

    @extra_info.setter
    def extra_info(self, extra_info):

        self.__extra_info = extra_info

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ApiResponseMetadata, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponseMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.security.v4.management.EventType import EventType  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.management.SecuredEntityType import SecuredEntityType  # noqa: F401,E501

class SecurityValidationSpec(object):

    """Specifications required to trigger a security validation job.

    :param secured_entity_type: (:attr:`secured_entity_type`) 
    :type secured_entity_type: required
    
    
    :param secured_entity_name: (:attr:`secured_entity_name`) Name of the secured entity.
    :type secured_entity_name: required
     min=4 chars, max=199 chars
    
    :param secured_entity_ext_id: (:attr:`secured_entity_ext_id`) UUID of the secured entity.
    :type secured_entity_ext_id: required
    
    
    :param event_type: (:attr:`event_type`) 
    :type event_type: required
    
    
    :param secured_policy_ext_id: (:attr:`secured_policy_ext_id`) UUID of secured policy
    :type secured_policy_ext_id: 
    
    
    :param secured_entity_location: (:attr:`secured_entity_location`) Location of the secured entity.
    :type secured_entity_location: 
    
    
    :param requester_ext_id: (:attr:`requester_ext_id`) IAM UUID of the requester.
    :type requester_ext_id: required
    
    
    :param fully_qualified_secured_entity_name: (:attr:`fully_qualified_secured_entity_name`) Qualified entity type. For example dataprotection:config:recovery-point
    :type fully_qualified_secured_entity_name: 
     max=199 chars
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'secured_entity_type': 'security.v4.management.SecuredEntityType',
        'secured_entity_name': 'str',
        'secured_entity_ext_id': 'str',
        'event_type': 'security.v4.management.EventType',
        'secured_policy_ext_id': 'str',
        'secured_entity_location': 'str',
        'requester_ext_id': 'str',
        'fully_qualified_secured_entity_name': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'secured_entity_type': 'securedEntityType',
        'secured_entity_name': 'securedEntityName',
        'secured_entity_ext_id': 'securedEntityExtId',
        'event_type': 'eventType',
        'secured_policy_ext_id': 'securedPolicyExtId',
        'secured_entity_location': 'securedEntityLocation',
        'requester_ext_id': 'requesterExtId',
        'fully_qualified_secured_entity_name': 'fullyQualifiedSecuredEntityName',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, secured_entity_type=None, secured_entity_name=None, secured_entity_ext_id=None, event_type=None, secured_policy_ext_id=None, secured_entity_location=None, requester_ext_id=None, fully_qualified_secured_entity_name=None, *args, **kwargs):  # noqa: E501
        self.__secured_entity_type = None
        self.__secured_entity_name = None
        self.__secured_entity_ext_id = None
        self.__event_type = None
        self.__secured_policy_ext_id = None
        self.__secured_entity_location = None
        self.__requester_ext_id = None
        self.__fully_qualified_secured_entity_name = None
        self.discriminator = None
        self.__secured_entity_type = secured_entity_type
        self.__secured_entity_name = secured_entity_name
        self.__secured_entity_ext_id = secured_entity_ext_id
        self.__event_type = event_type
        if secured_policy_ext_id is not None:
            self.__secured_policy_ext_id = secured_policy_ext_id
        if secured_entity_location is not None:
            self.__secured_entity_location = secured_entity_location
        self.__requester_ext_id = requester_ext_id
        if fully_qualified_secured_entity_name is not None:
            self.__fully_qualified_secured_entity_name = fully_qualified_secured_entity_name
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'security.v4.management.SecurityValidationSpec'

    def _initialize_object_version(self):
        return 'v4.r0'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def secured_entity_type(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.management.SecuredEntityType`
        """  # noqa: E501
        return self.__secured_entity_type

    @secured_entity_type.setter
    def secured_entity_type(self, secured_entity_type):
        if secured_entity_type is None:
            raise ValueError("Invalid value for `secured_entity_type`, must not be `None`")  # noqa: E501

        self.__secured_entity_type = secured_entity_type

    @property
    def secured_entity_name(self):
        """
        Name of the secured entity.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__secured_entity_name

    @secured_entity_name.setter
    def secured_entity_name(self, secured_entity_name):
        if secured_entity_name is None:
            raise ValueError("Invalid value for `secured_entity_name`, must not be `None`")  # noqa: E501
        if secured_entity_name is not None and len(secured_entity_name) > 199:
            raise ValueError("Invalid value for `secured_entity_name`, length must be less than or equal to `199`")  # noqa: E501
        if secured_entity_name is not None and len(secured_entity_name) < 4:
            raise ValueError("Invalid value for `secured_entity_name`, length must be greater than or equal to `4`")  # noqa: E501

        self.__secured_entity_name = secured_entity_name

    @property
    def secured_entity_ext_id(self):
        """
        UUID of the secured entity.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__secured_entity_ext_id

    @secured_entity_ext_id.setter
    def secured_entity_ext_id(self, secured_entity_ext_id):
        if secured_entity_ext_id is None:
            raise ValueError("Invalid value for `secured_entity_ext_id`, must not be `None`")  # noqa: E501
        if secured_entity_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', secured_entity_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `secured_entity_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__secured_entity_ext_id = secured_entity_ext_id

    @property
    def event_type(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.management.EventType`
        """  # noqa: E501
        return self.__event_type

    @event_type.setter
    def event_type(self, event_type):
        if event_type is None:
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501

        self.__event_type = event_type

    @property
    def secured_policy_ext_id(self):
        """
        UUID of secured policy

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__secured_policy_ext_id

    @secured_policy_ext_id.setter
    def secured_policy_ext_id(self, secured_policy_ext_id):
        if secured_policy_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', secured_policy_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `secured_policy_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__secured_policy_ext_id = secured_policy_ext_id

    @property
    def secured_entity_location(self):
        """
        Location of the secured entity.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__secured_entity_location

    @secured_entity_location.setter
    def secured_entity_location(self, secured_entity_location):
        if secured_entity_location is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', secured_entity_location):  # noqa: E501
            raise ValueError(r"Invalid value for `secured_entity_location`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__secured_entity_location = secured_entity_location

    @property
    def requester_ext_id(self):
        """
        IAM UUID of the requester.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__requester_ext_id

    @requester_ext_id.setter
    def requester_ext_id(self, requester_ext_id):
        if requester_ext_id is None:
            raise ValueError("Invalid value for `requester_ext_id`, must not be `None`")  # noqa: E501
        if requester_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', requester_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `requester_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__requester_ext_id = requester_ext_id

    @property
    def fully_qualified_secured_entity_name(self):
        """
        Qualified entity type. For example dataprotection:config:recovery-point

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__fully_qualified_secured_entity_name

    @fully_qualified_secured_entity_name.setter
    def fully_qualified_secured_entity_name(self, fully_qualified_secured_entity_name):
        if fully_qualified_secured_entity_name is not None and len(fully_qualified_secured_entity_name) > 199:
            raise ValueError("Invalid value for `fully_qualified_secured_entity_name`, length must be less than or equal to `199`")  # noqa: E501

        self.__fully_qualified_secured_entity_name = fully_qualified_secured_entity_name

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(SecurityValidationSpec, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityValidationSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501

class SecurityConfigVisibilitySetting(ExternalizableAbstractModel):

    """Contains the configuration for PC UI visibility status of all security configs settings.

    :param is_high_strength_password_visible: (:attr:`is_high_strength_password_visible`) Represents the visibility of high strength password state.
    :type is_high_strength_password_visible: 
    
    
    :param is_aide_visible: (:attr:`is_aide_visible`) Represents the visibility of aide service state.
    :type is_aide_visible: 
    
    
    :param is_scma_visible: (:attr:`is_scma_visible`) Represents the visibility of security configuration management automation state.
    :type is_scma_visible: 
    
    
    :param is_secure_boot_visible: (:attr:`is_secure_boot_visible`) Represents the visibility of host secure boot state.
    :type is_secure_boot_visible: 
    
    
    :param is_network_segmentation_visible: (:attr:`is_network_segmentation_visible`) Represents the visibility of network segmentation state.
    :type is_network_segmentation_visible: 
    
    
    :param is_cluster_lockdown_visible: (:attr:`is_cluster_lockdown_visible`) Represents the visibility of cluster lockdown state.
    :type is_cluster_lockdown_visible: 
    
    
    :param is_log_forwarding_visible: (:attr:`is_log_forwarding_visible`) Represents the visibility of log forwarding state.
    :type is_log_forwarding_visible: 
    
    
    :param is_defense_consent_banner_visible: (:attr:`is_defense_consent_banner_visible`) Represents the visibility of banner state.
    :type is_defense_consent_banner_visible: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'is_high_strength_password_visible': 'bool',
        'is_aide_visible': 'bool',
        'is_scma_visible': 'bool',
        'is_secure_boot_visible': 'bool',
        'is_network_segmentation_visible': 'bool',
        'is_cluster_lockdown_visible': 'bool',
        'is_log_forwarding_visible': 'bool',
        'is_defense_consent_banner_visible': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'is_high_strength_password_visible': 'isHighStrengthPasswordVisible',
        'is_aide_visible': 'isAideVisible',
        'is_scma_visible': 'isScmaVisible',
        'is_secure_boot_visible': 'isSecureBootVisible',
        'is_network_segmentation_visible': 'isNetworkSegmentationVisible',
        'is_cluster_lockdown_visible': 'isClusterLockdownVisible',
        'is_log_forwarding_visible': 'isLogForwardingVisible',
        'is_defense_consent_banner_visible': 'isDefenseConsentBannerVisible',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, is_high_strength_password_visible=None, is_aide_visible=None, is_scma_visible=None, is_secure_boot_visible=None, is_network_segmentation_visible=None, is_cluster_lockdown_visible=None, is_log_forwarding_visible=None, is_defense_consent_banner_visible=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__is_high_strength_password_visible = None
        self.__is_aide_visible = None
        self.__is_scma_visible = None
        self.__is_secure_boot_visible = None
        self.__is_network_segmentation_visible = None
        self.__is_cluster_lockdown_visible = None
        self.__is_log_forwarding_visible = None
        self.__is_defense_consent_banner_visible = None
        self.discriminator = None
        if is_high_strength_password_visible is not None:
            self.__is_high_strength_password_visible = is_high_strength_password_visible
        if is_aide_visible is not None:
            self.__is_aide_visible = is_aide_visible
        if is_scma_visible is not None:
            self.__is_scma_visible = is_scma_visible
        if is_secure_boot_visible is not None:
            self.__is_secure_boot_visible = is_secure_boot_visible
        if is_network_segmentation_visible is not None:
            self.__is_network_segmentation_visible = is_network_segmentation_visible
        if is_cluster_lockdown_visible is not None:
            self.__is_cluster_lockdown_visible = is_cluster_lockdown_visible
        if is_log_forwarding_visible is not None:
            self.__is_log_forwarding_visible = is_log_forwarding_visible
        if is_defense_consent_banner_visible is not None:
            self.__is_defense_consent_banner_visible = is_defense_consent_banner_visible

    def _initialize_object_type(self):
        return 'security.v4.config.SecurityConfigVisibilitySetting'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def is_high_strength_password_visible(self):
        """
        Represents the visibility of high strength password state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_high_strength_password_visible

    @is_high_strength_password_visible.setter
    def is_high_strength_password_visible(self, is_high_strength_password_visible):

        self.__is_high_strength_password_visible = is_high_strength_password_visible

    @property
    def is_aide_visible(self):
        """
        Represents the visibility of aide service state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_aide_visible

    @is_aide_visible.setter
    def is_aide_visible(self, is_aide_visible):

        self.__is_aide_visible = is_aide_visible

    @property
    def is_scma_visible(self):
        """
        Represents the visibility of security configuration management automation state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_scma_visible

    @is_scma_visible.setter
    def is_scma_visible(self, is_scma_visible):

        self.__is_scma_visible = is_scma_visible

    @property
    def is_secure_boot_visible(self):
        """
        Represents the visibility of host secure boot state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_secure_boot_visible

    @is_secure_boot_visible.setter
    def is_secure_boot_visible(self, is_secure_boot_visible):

        self.__is_secure_boot_visible = is_secure_boot_visible

    @property
    def is_network_segmentation_visible(self):
        """
        Represents the visibility of network segmentation state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_network_segmentation_visible

    @is_network_segmentation_visible.setter
    def is_network_segmentation_visible(self, is_network_segmentation_visible):

        self.__is_network_segmentation_visible = is_network_segmentation_visible

    @property
    def is_cluster_lockdown_visible(self):
        """
        Represents the visibility of cluster lockdown state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_cluster_lockdown_visible

    @is_cluster_lockdown_visible.setter
    def is_cluster_lockdown_visible(self, is_cluster_lockdown_visible):

        self.__is_cluster_lockdown_visible = is_cluster_lockdown_visible

    @property
    def is_log_forwarding_visible(self):
        """
        Represents the visibility of log forwarding state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_log_forwarding_visible

    @is_log_forwarding_visible.setter
    def is_log_forwarding_visible(self, is_log_forwarding_visible):

        self.__is_log_forwarding_visible = is_log_forwarding_visible

    @property
    def is_defense_consent_banner_visible(self):
        """
        Represents the visibility of banner state.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_defense_consent_banner_visible

    @is_defense_consent_banner_visible.setter
    def is_defense_consent_banner_visible(self, is_defense_consent_banner_visible):

        self.__is_defense_consent_banner_visible = is_defense_consent_banner_visible

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(SecurityConfigVisibilitySetting, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityConfigVisibilitySetting):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ntnx_security_py_client.api_client import ApiClient


class ApprovalPoliciesApi(object):
    """IGNORE:
    NOTE: A placeholder for class level description
    IGNORE
    """  # noqa: E501

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()

        self.api_client = api_client
        self.__headers_to_skip = { 'authorization', 'cookie', 'host', 'user-agent' }

    def associate_policies(self, extId, body, **kwargs):  # noqa: E501
        """Update list of secured policies

        >>> response = api.associate_policies(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.associate_policies(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: Approval policy external identifier.
        :type extId:
            :class:`str`, required
        :param body: 
        :type body:
            :class:`~ntnx_security_py_client.models.security.v4.management.AssociatePoliciesSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_security_py_client.models.security.v4.management.AssociatePoliciesApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `associate_policies`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `associate_policies`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies/{extId}/$actions/associate-policies', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.AssociatePoliciesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies/{extId}/$actions/associate-policies', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.AssociatePoliciesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def create_approval_policy(self, body, **kwargs):  # noqa: E501
        """Create an approval policy

        >>> response = api.create_approval_policy(body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.create_approval_policy(body, async_req=True)
        >>> result = thread.get()

        :param body: Details used to create an approval policy.
        :type body:
            :class:`~ntnx_security_py_client.models.security.v4.management.ApprovalPolicy`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_security_py_client.models.security.v4.management.CreateApprovalPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_approval_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.CreateApprovalPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.CreateApprovalPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def get_approval_policy_by_ext_id(self, extId, _select=None, **kwargs):  # noqa: E501
        """Get an approval policy details

        >>> response = api.get_approval_policy_by_ext_id(extId, (optional) _select)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_approval_policy_by_ext_id(extId, async_req=True)
        >>> result = thread.get()

        :param extId: Approval policy external identifier.
        :type extId:
            :class:`str`, required
        :param _select: A URL query parameter that allows clients to request a specific set of properties for each entity or complex type. Expression specified with the $select must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. If a $select expression consists of a single select item that is an asterisk (i.e., *), then all properties on the matching resource will be returned.
        :type _select:
            :class:`str`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_security_py_client.models.security.v4.management.GetApprovalPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `get_approval_policy_by_ext_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []
        if '_select' in params and params['_select'] is not None:
            query_params.append(('$select', params['_select']))  # noqa: E501

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', '_select'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.GetApprovalPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.GetApprovalPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def list_approval_policies(self, _filter=None, _orderby=None, _select=None, **kwargs):  # noqa: E501
        """List approval policies

        >>> response = api.list_approval_policies((optional) _filter, (optional) _orderby, (optional) _select)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.list_approval_policies(async_req=True)
        >>> result = thread.get()

        :param _filter: A URL query parameter that allows clients to filter a collection of resources. The expression specified with $filter is evaluated for each resource in the collection, and only items where the expression evaluates to true are included in the response. Expression specified with the $filter must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. For example, filter '$filter=name eq 'karbon-ntnx-1.0' would filter the result on cluster name 'karbon-ntnx1.0', filter '$filter=startswith(name, 'C')' would filter on cluster name starting with 'C'.
        :type _filter:
            :class:`str`
        :param _orderby: A URL query parameter that allows clients to specify the sort criteria for the returned list of objects. Resources can be sorted in ascending order using asc or descending order using desc. If asc or desc are not specified, the resources will be sorted in ascending order by default. For example, '$orderby=templateName desc' would get all templates sorted by templateName in descending order.
        :type _orderby:
            :class:`str`
        :param _select: A URL query parameter that allows clients to request a specific set of properties for each entity or complex type. Expression specified with the $select must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. If a $select expression consists of a single select item that is an asterisk (i.e., *), then all properties on the matching resource will be returned.
        :type _select:
            :class:`str`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_security_py_client.models.security.v4.management.ListApprovalPoliciesApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']


        collection_formats = {}

        path_params = {}

        query_params = []
        if '_filter' in params and params['_filter'] is not None:
            query_params.append(('$filter', params['_filter']))  # noqa: E501
        if '_orderby' in params and params['_orderby'] is not None:
            query_params.append(('$orderby', params['_orderby']))  # noqa: E501
        if '_select' in params and params['_select'] is not None:
            query_params.append(('$select', params['_select']))  # noqa: E501

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['_filter', '_orderby', '_select'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.ListApprovalPoliciesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.ListApprovalPoliciesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def update_approval_policy_by_ext_id(self, extId, body, **kwargs):  # noqa: E501
        """Update the details of a specific approval policy

        >>> response = api.update_approval_policy_by_ext_id(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.update_approval_policy_by_ext_id(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: Approval policy external identifier.
        :type extId:
            :class:`str`, required
        :param body: 
        :type body:
            :class:`~ntnx_security_py_client.models.security.v4.management.ApprovalPolicy`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_security_py_client.models.security.v4.management.UpdateApprovalPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `update_approval_policy_by_ext_id`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_approval_policy_by_ext_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies/{extId}', 'PUT',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.UpdateApprovalPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/security/v4.0/management/approval-policies/{extId}', 'PUT',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='security.v4.management.UpdateApprovalPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass



# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path

class AzureAccessInformation(object):

    """Access information for the Azure Key Vault.

    :param endpoint_url: (:attr:`endpoint_url`) Endpoint URL for the Azure Key Vault.
    :type endpoint_url: required
     max=1024 chars
    
    :param key_id: (:attr:`key_id`) Master key identifier for the Azure Key Vault.
    :type key_id: required
     max=256 chars
    
    :param tenant_id: (:attr:`tenant_id`) Tetant identifier for the Azure Key Vault.
    :type tenant_id: required
     max=256 chars
    
    :param client_id: (:attr:`client_id`) Client identifier for the Azure Key Vault.
    :type client_id: required
     max=256 chars
    
    :param client_secret: (:attr:`client_secret`) Client secret for the Azure Key Vault.
    :type client_secret: required
    
    
    :param truncated_client_secret: (:attr:`truncated_client_secret`) Truncated client secret for the Azure Key Vault.
    :type truncated_client_secret: 
     min=8 chars, max=256 chars
    
    :param credential_expiry_date: (:attr:`credential_expiry_date`) When the client secret is going to expire.
    :type credential_expiry_date: required
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'endpoint_url': 'str',
        'key_id': 'str',
        'tenant_id': 'str',
        'client_id': 'str',
        'client_secret': 'str',
        'truncated_client_secret': 'str',
        'credential_expiry_date': 'date',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'endpoint_url': 'endpointUrl',
        'key_id': 'keyId',
        'tenant_id': 'tenantId',
        'client_id': 'clientId',
        'client_secret': 'clientSecret',
        'truncated_client_secret': 'truncatedClientSecret',
        'credential_expiry_date': 'credentialExpiryDate',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, endpoint_url=None, key_id=None, tenant_id=None, client_id=None, client_secret=None, truncated_client_secret=None, credential_expiry_date=None, *args, **kwargs):  # noqa: E501
        self.__endpoint_url = None
        self.__key_id = None
        self.__tenant_id = None
        self.__client_id = None
        self.__client_secret = None
        self.__truncated_client_secret = None
        self.__credential_expiry_date = None
        self.discriminator = None
        self.__endpoint_url = endpoint_url
        self.__key_id = key_id
        self.__tenant_id = tenant_id
        self.__client_id = client_id
        self.__client_secret = client_secret
        if truncated_client_secret is not None:
            self.__truncated_client_secret = truncated_client_secret
        self.__credential_expiry_date = credential_expiry_date
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'security.v4.config.AzureAccessInformation'

    def _initialize_object_version(self):
        return 'v4.r0'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def endpoint_url(self):
        """
        Endpoint URL for the Azure Key Vault.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__endpoint_url

    @endpoint_url.setter
    def endpoint_url(self, endpoint_url):
        if endpoint_url is None:
            raise ValueError("Invalid value for `endpoint_url`, must not be `None`")  # noqa: E501
        if endpoint_url is not None and len(endpoint_url) > 1024:
            raise ValueError("Invalid value for `endpoint_url`, length must be less than or equal to `1024`")  # noqa: E501
        if endpoint_url is not None and not re.search('^((http[s]?|nfs):\/)?\/?([^:\/\\s]*)((\/\\w+)*(:[0-9]+)*?\/)([\\w\\-\\.]+[^#?\\s]+)(.*)?(#[\\w\\-]+)?$', endpoint_url):  # noqa: E501
            raise ValueError(r"Invalid value for `endpoint_url`, must be a follow pattern or equal to `/^((http[s]?|nfs):\/)?\/?([^:\/\\s]*)((\/\\w+)*(:[0-9]+)*?\/)([\\w\\-\\.]+[^#?\\s]+)(.*)?(#[\\w\\-]+)?$/`")  # noqa: E501

        self.__endpoint_url = endpoint_url

    @property
    def key_id(self):
        """
        Master key identifier for the Azure Key Vault.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__key_id

    @key_id.setter
    def key_id(self, key_id):
        if key_id is None:
            raise ValueError("Invalid value for `key_id`, must not be `None`")  # noqa: E501
        if key_id is not None and len(key_id) > 256:
            raise ValueError("Invalid value for `key_id`, length must be less than or equal to `256`")  # noqa: E501

        self.__key_id = key_id

    @property
    def tenant_id(self):
        """
        Tetant identifier for the Azure Key Vault.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        if tenant_id is None:
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501
        if tenant_id is not None and len(tenant_id) > 256:
            raise ValueError("Invalid value for `tenant_id`, length must be less than or equal to `256`")  # noqa: E501

        self.__tenant_id = tenant_id

    @property
    def client_id(self):
        """
        Client identifier for the Azure Key Vault.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__client_id

    @client_id.setter
    def client_id(self, client_id):
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501
        if client_id is not None and len(client_id) > 256:
            raise ValueError("Invalid value for `client_id`, length must be less than or equal to `256`")  # noqa: E501

        self.__client_id = client_id

    @property
    def client_secret(self):
        """
        Client secret for the Azure Key Vault.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        if client_secret is None:
            raise ValueError("Invalid value for `client_secret`, must not be `None`")  # noqa: E501

        self.__client_secret = client_secret

    @property
    def truncated_client_secret(self):
        """
        Truncated client secret for the Azure Key Vault.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__truncated_client_secret

    @truncated_client_secret.setter
    def truncated_client_secret(self, truncated_client_secret):
        if truncated_client_secret is not None and len(truncated_client_secret) > 256:
            raise ValueError("Invalid value for `truncated_client_secret`, length must be less than or equal to `256`")  # noqa: E501
        if truncated_client_secret is not None and len(truncated_client_secret) < 8:
            raise ValueError("Invalid value for `truncated_client_secret`, length must be greater than or equal to `8`")  # noqa: E501

        self.__truncated_client_secret = truncated_client_secret

    @property
    def credential_expiry_date(self):
        """
        When the client secret is going to expire.

        :type:
                :class:`~date`
        """  # noqa: E501
        return self.__credential_expiry_date

    @credential_expiry_date.setter
    def credential_expiry_date(self, credential_expiry_date):
        if credential_expiry_date is None:
            raise ValueError("Invalid value for `credential_expiry_date`, must not be `None`")  # noqa: E501

        self.__credential_expiry_date = credential_expiry_date

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(AzureAccessInformation, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AzureAccessInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_security_py_client.models
from ntnx_security_py_client.models.OneOfsecurity.v4.config.Credentialcredential_details import Credentialcredential_details  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501

class Credential(ExternalizableAbstractModel):

    """

    :param name: (:attr:`name`) Name of the credential.
    :type name: required
     min=1 chars, max=256 chars
    
    :param credential_details: (:attr:`credential_details`) Details of the credential authentication parameters.
    :type credential_details: required
    
    
    :param is_valid: (:attr:`is_valid`) Indicates if the credential is valid.
    :type is_valid: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'credential_details': 'OneOfsecurity.v4.config.Credentialcredential_details',
        'is_valid': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'credential_details': 'credentialDetails',
        'is_valid': 'isValid',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, credential_details=None, is_valid=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__name = None
        self.__credential_details = None
        self.__is_valid = None
        self.discriminator = None
        self.__name = name
        self.__credential_details = credential_details
        if is_valid is not None:
            self.__is_valid = is_valid

    def _initialize_object_type(self):
        return 'security.v4.config.Credential'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def name(self):
        """
        Name of the credential.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 256:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")  # noqa: E501
        if name is not None and len(name) < 1:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self.__name = name

    @property
    def credential_details(self):
        """
        Details of the credential authentication parameters.

        :type:
                :class:`~ntnx_security_py_client.models.security.v4.config.BmcCredential` | 
                :class:`~ntnx_security_py_client.models.security.v4.config.VcenterCredential` | 
                :class:`~ntnx_security_py_client.models.security.v4.config.IntersightCredential`
        """  # noqa: E501
        return self.__credential_details

    @credential_details.setter
    def credential_details(self, credential_details):
        if credential_details is None:
            raise ValueError("Invalid value for `credential_details`, must not be `None`")  # noqa: E501

        self.__credential_details = credential_details

    @property
    def is_valid(self):
        """
        Indicates if the credential is valid.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_valid

    @is_valid.setter
    def is_valid(self, is_valid):

        self.__is_valid = is_valid

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_security_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(Credential, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Credential):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import io
import os
from setuptools import setup, find_packages  # noqa: H301

NAME = "ntnx-security-py-client"
VERSION = "4.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 ~= 1.26", "six ~= 1.16", "certifi >=2020.4.5.1,<=2023.11.17", "python-dateutil ~= 2.8", "pysocks ~= 1.7"]

package_root_path = os.path.abspath(os.path.dirname(__file__))
readme_file_path = os.path.join(package_root_path, "README.md")
with io.open(readme_file_path, encoding="utf-8") as readme_file:
    readme = readme_file.read()

setup(
    name=NAME,
    version=VERSION,
    description="Nutanix Security APIs",
    author_email="sdk@nutanix.com",
    url="",
    keywords=["Nutanix", "v4", "SDK", "Nutanix Security APIs"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=readme,
    long_description_content_type="text/markdown",
)



# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.security.v4.common.ClusterProjection import ClusterProjection  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.config.ScheduleType import ScheduleType  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.config.SecurityConfig import SecurityConfig  # noqa: F401,E501

class SecurityConfigProjection(SecurityConfig):

    """

    :param cluster_projection: (:attr:`cluster_projection`) 
    :type cluster_projection: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'cluster_projection': 'security.v4.common.ClusterProjection',
        'cluster_ext_id': 'str',
        'is_high_strength_password_enabled': 'bool',
        'is_aide_enabled': 'bool',
        'is_secure_boot_enabled': 'bool',
        'is_cluster_lockdown_enabled': 'bool',
        'is_log_forwarding_enabled': 'bool',
        'cluster_scma_schedule': 'security.v4.config.ScheduleType',
        'ahv_scma_schedule': 'security.v4.config.ScheduleType',
        'is_ahv_defense_consent_banner_enabled': 'bool',
        'is_cluster_defense_consent_banner_enabled': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'cluster_projection': 'clusterProjection',
        'cluster_ext_id': 'clusterExtId',
        'is_high_strength_password_enabled': 'isHighStrengthPasswordEnabled',
        'is_aide_enabled': 'isAideEnabled',
        'is_secure_boot_enabled': 'isSecureBootEnabled',
        'is_cluster_lockdown_enabled': 'isClusterLockdownEnabled',
        'is_log_forwarding_enabled': 'isLogForwardingEnabled',
        'cluster_scma_schedule': 'clusterScmaSchedule',
        'ahv_scma_schedule': 'ahvScmaSchedule',
        'is_ahv_defense_consent_banner_enabled': 'isAhvDefenseConsentBannerEnabled',
        'is_cluster_defense_consent_banner_enabled': 'isClusterDefenseConsentBannerEnabled',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, cluster_projection=None, cluster_ext_id=None, is_high_strength_password_enabled=False, is_aide_enabled=False, is_secure_boot_enabled=False, is_cluster_lockdown_enabled=False, is_log_forwarding_enabled=False, cluster_scma_schedule=None, ahv_scma_schedule=None, is_ahv_defense_consent_banner_enabled=False, is_cluster_defense_consent_banner_enabled=False, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        SecurityConfig.__init__(self, cluster_ext_id, is_high_strength_password_enabled, is_aide_enabled, is_secure_boot_enabled, is_cluster_lockdown_enabled, is_log_forwarding_enabled, cluster_scma_schedule, ahv_scma_schedule, is_ahv_defense_consent_banner_enabled, is_cluster_defense_consent_banner_enabled, ext_id, links, tenant_id, *args, **kwargs)
        self.__cluster_projection = None
        self.discriminator = None
        if cluster_projection is not None:
            self.__cluster_projection = cluster_projection

    def _initialize_object_type(self):
        return 'security.v4.config.SecurityConfigProjection'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def cluster_projection(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.common.ClusterProjection`
        """  # noqa: E501
        return self.__cluster_projection

    @cluster_projection.setter
    def cluster_projection(self, cluster_projection):

        self.__cluster_projection = cluster_projection

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(SecurityConfigProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityConfigProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.management.ApproverGroup import ApproverGroup  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.management.SecuredPolicy import SecuredPolicy  # noqa: F401,E501

class ApprovalPolicy(ExternalizableAbstractModel):

    """Specification of the configured approval policy.

    :param name: (:attr:`name`) Name of the approval policy.
    :type name: required
     min=4 chars, max=199 chars
    
    :param description: (:attr:`description`) Description of the approval policy.
    :type description: 
     max=499 chars
    
    :param approver_groups: (:attr:`approver_groups`) List of approver sets.
    :type approver_groups: required
    
    
    :param secured_policies: (:attr:`secured_policies`) List of secured policies.
    :type secured_policies: 
    
    
    :param last_updated_by: (:attr:`last_updated_by`) The user who last updated the approval policy.
    :type last_updated_by: 
    
    
    :param last_update_time: (:attr:`last_update_time`) The timestamp of the last update of the approval policy.
    :type last_update_time: 
    
    
    :param is_update_pending: (:attr:`is_update_pending`) Current update status of the approval request update.
    :type is_update_pending: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'approver_groups': 'list[security.v4.management.ApproverGroup]',
        'secured_policies': 'list[security.v4.management.SecuredPolicy]',
        'last_updated_by': 'str',
        'last_update_time': 'datetime',
        'is_update_pending': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'approver_groups': 'approverGroups',
        'secured_policies': 'securedPolicies',
        'last_updated_by': 'lastUpdatedBy',
        'last_update_time': 'lastUpdateTime',
        'is_update_pending': 'isUpdatePending',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, description=None, approver_groups=None, secured_policies=None, last_updated_by=None, last_update_time=None, is_update_pending=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__name = None
        self.__description = None
        self.__approver_groups = None
        self.__secured_policies = None
        self.__last_updated_by = None
        self.__last_update_time = None
        self.__is_update_pending = None
        self.discriminator = None
        self.__name = name
        if description is not None:
            self.__description = description
        self.__approver_groups = approver_groups
        if secured_policies is not None:
            self.__secured_policies = secured_policies
        if last_updated_by is not None:
            self.__last_updated_by = last_updated_by
        if last_update_time is not None:
            self.__last_update_time = last_update_time
        if is_update_pending is not None:
            self.__is_update_pending = is_update_pending

    def _initialize_object_type(self):
        return 'security.v4.management.ApprovalPolicy'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def name(self):
        """
        Name of the approval policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 199:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `199`")  # noqa: E501
        if name is not None and len(name) < 4:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `4`")  # noqa: E501

        self.__name = name

    @property
    def description(self):
        """
        Description of the approval policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__description

    @description.setter
    def description(self, description):
        if description is not None and len(description) > 499:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `499`")  # noqa: E501

        self.__description = description

    @property
    def approver_groups(self):
        """
        List of approver sets.

        :type:
             list[ :class:`~ntnx_security_py_client.models.security.v4.management.ApproverGroup` ]
        """  # noqa: E501
        return self.__approver_groups

    @approver_groups.setter
    def approver_groups(self, approver_groups):
        if approver_groups is None:
            raise ValueError("Invalid value for `approver_groups`, must not be `None`")  # noqa: E501

        self.__approver_groups = approver_groups

    @property
    def secured_policies(self):
        """
        List of secured policies.

        :type:
             list[ :class:`~ntnx_security_py_client.models.security.v4.management.SecuredPolicy` ]
        """  # noqa: E501
        return self.__secured_policies

    @secured_policies.setter
    def secured_policies(self, secured_policies):

        self.__secured_policies = secured_policies

    @property
    def last_updated_by(self):
        """
        The user who last updated the approval policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, last_updated_by):

        self.__last_updated_by = last_updated_by

    @property
    def last_update_time(self):
        """
        The timestamp of the last update of the approval policy.

        :type:
                :class:`~datetime`
        """  # noqa: E501
        return self.__last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):

        self.__last_update_time = last_update_time

    @property
    def is_update_pending(self):
        """
        Current update status of the approval request update.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_update_pending

    @is_update_pending.setter
    def is_update_pending(self, is_update_pending):

        self.__is_update_pending = is_update_pending

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ApprovalPolicy, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApprovalPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_security_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_security_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.common.Timescale import Timescale  # noqa: F401,E501
from ntnx_security_py_client.models.security.v4.report.IssueSummary import IssueSummary  # noqa: F401,E501

class Summary(ExternalizableAbstractModel):

    """Number of security related issues for a single cluster

    :param cluster_ext_id: (:attr:`cluster_ext_id`) UUID of the cluster.
    :type cluster_ext_id: 
    
    
    :param security_config_summary: (:attr:`security_config_summary`) 
    :type security_config_summary: 
    
    
    :param stig_summary: (:attr:`stig_summary`) 
    :type stig_summary: 
    
    
    :param vulnerabilities_summary: (:attr:`vulnerabilities_summary`) 
    :type vulnerabilities_summary: 
    
    
    :param password_summary: (:attr:`password_summary`) 
    :type password_summary: 
    
    
    :param trend_type: (:attr:`trend_type`) 
    :type trend_type: 
    
    
    :param last_refresh_time: (:attr:`last_refresh_time`) The date the dashboard information was last refreshed
    :type last_refresh_time: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'cluster_ext_id': 'str',
        'security_config_summary': 'security.v4.report.IssueSummary',
        'stig_summary': 'security.v4.report.IssueSummary',
        'vulnerabilities_summary': 'security.v4.report.IssueSummary',
        'password_summary': 'security.v4.report.IssueSummary',
        'trend_type': 'security.v4.common.Timescale',
        'last_refresh_time': 'datetime',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'cluster_ext_id': 'clusterExtId',
        'security_config_summary': 'securityConfigSummary',
        'stig_summary': 'stigSummary',
        'vulnerabilities_summary': 'vulnerabilitiesSummary',
        'password_summary': 'passwordSummary',
        'trend_type': 'trendType',
        'last_refresh_time': 'lastRefreshTime',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, cluster_ext_id=None, security_config_summary=None, stig_summary=None, vulnerabilities_summary=None, password_summary=None, trend_type=None, last_refresh_time=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__cluster_ext_id = None
        self.__security_config_summary = None
        self.__stig_summary = None
        self.__vulnerabilities_summary = None
        self.__password_summary = None
        self.__trend_type = None
        self.__last_refresh_time = None
        self.discriminator = None
        if cluster_ext_id is not None:
            self.__cluster_ext_id = cluster_ext_id
        if security_config_summary is not None:
            self.__security_config_summary = security_config_summary
        if stig_summary is not None:
            self.__stig_summary = stig_summary
        if vulnerabilities_summary is not None:
            self.__vulnerabilities_summary = vulnerabilities_summary
        if password_summary is not None:
            self.__password_summary = password_summary
        if trend_type is not None:
            self.__trend_type = trend_type
        if last_refresh_time is not None:
            self.__last_refresh_time = last_refresh_time

    def _initialize_object_type(self):
        return 'security.v4.report.Summary'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def cluster_ext_id(self):
        """
        UUID of the cluster.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__cluster_ext_id

    @cluster_ext_id.setter
    def cluster_ext_id(self, cluster_ext_id):
        if cluster_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', cluster_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `cluster_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__cluster_ext_id = cluster_ext_id

    @property
    def security_config_summary(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.report.IssueSummary`
        """  # noqa: E501
        return self.__security_config_summary

    @security_config_summary.setter
    def security_config_summary(self, security_config_summary):

        self.__security_config_summary = security_config_summary

    @property
    def stig_summary(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.report.IssueSummary`
        """  # noqa: E501
        return self.__stig_summary

    @stig_summary.setter
    def stig_summary(self, stig_summary):

        self.__stig_summary = stig_summary

    @property
    def vulnerabilities_summary(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.report.IssueSummary`
        """  # noqa: E501
        return self.__vulnerabilities_summary

    @vulnerabilities_summary.setter
    def vulnerabilities_summary(self, vulnerabilities_summary):

        self.__vulnerabilities_summary = vulnerabilities_summary

    @property
    def password_summary(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.report.IssueSummary`
        """  # noqa: E501
        return self.__password_summary

    @password_summary.setter
    def password_summary(self, password_summary):

        self.__password_summary = password_summary

    @property
    def trend_type(self):
        """
        

        :type:
            :class:`~ntnx_security_py_client.models.security.v4.common.Timescale`
        """  # noqa: E501
        return self.__trend_type

    @trend_type.setter
    def trend_type(self, trend_type):

        self.__trend_type = trend_type

    @property
    def last_refresh_time(self):
        """
        The date the dashboard information was last refreshed

        :type:
                :class:`~datetime`
        """  # noqa: E501
        return self.__last_refresh_time

    @last_refresh_time.setter
    def last_refresh_time(self, last_refresh_time):

        self.__last_refresh_time = last_refresh_time

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(Summary, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Summary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8

# flake8: noqa


"""
IGNORE:
    Nutanix Security APIs

    Manage security features, such as encryption, certificates, or platform hardening.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

# import apis into sdk package
from ntnx_security_py_client.api.approval_policies_api import ApprovalPoliciesApi
from ntnx_security_py_client.api.credentials_api import CredentialsApi
from ntnx_security_py_client.api.key_management_servers_api import KeyManagementServersApi
from ntnx_security_py_client.api.sti_gs_api import STIGsApi
# import ApiClient
from ntnx_security_py_client.api_client import ApiClient
from ntnx_security_py_client.configuration import Configuration
# import models into sdk package
from ntnx_security_py_client.models.OneOfcommon.v1.config.KVPairvalue import KVPairvalue
from ntnx_security_py_client.models.OneOfsecurity.v4.config.CreateCredentialApiResponsedata import CreateCredentialApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.CreateKeyManagementServerApiResponsedata import CreateKeyManagementServerApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.Credentialcredential_details import Credentialcredential_details
from ntnx_security_py_client.models.OneOfsecurity.v4.config.DeleteCredentialApiResponsedata import DeleteCredentialApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.DeleteKeyManagementServerApiResponsedata import DeleteKeyManagementServerApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.GetCredentialApiResponsedata import GetCredentialApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.GetKeyManagementServerApiResponsedata import GetKeyManagementServerApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.ListCredentialsApiResponsedata import ListCredentialsApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.ListKeyManagementServersApiResponsedata import ListKeyManagementServersApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.UpdateCredentialApiResponsedata import UpdateCredentialApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.config.UpdateKeyManagementServerApiResponsedata import UpdateKeyManagementServerApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.error.ErrorResponseerror import ErrorResponseerror
from ntnx_security_py_client.models.OneOfsecurity.v4.management.AssociatePoliciesApiResponsedata import AssociatePoliciesApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.management.CreateApprovalPolicyApiResponsedata import CreateApprovalPolicyApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.management.GetApprovalPolicyApiResponsedata import GetApprovalPolicyApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.management.ListApprovalPoliciesApiResponsedata import ListApprovalPoliciesApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.management.UpdateApprovalPolicyApiResponsedata import UpdateApprovalPolicyApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.report.ListStigSummariesApiResponsedata import ListStigSummariesApiResponsedata
from ntnx_security_py_client.models.OneOfsecurity.v4.report.ListStigsApiResponsedata import ListStigsApiResponsedata
from ntnx_security_py_client.models.common.v1.config.BasicAuth import BasicAuth
from ntnx_security_py_client.models.common.v1.config.FQDN import FQDN
from ntnx_security_py_client.models.common.v1.config.Flag import Flag
from ntnx_security_py_client.models.common.v1.config.IPAddressOrFQDN import IPAddressOrFQDN
from ntnx_security_py_client.models.common.v1.config.IPv4Address import IPv4Address
from ntnx_security_py_client.models.common.v1.config.IPv6Address import IPv6Address
from ntnx_security_py_client.models.common.v1.config.KVPair import KVPair
from ntnx_security_py_client.models.common.v1.config.MapOfStringWrapper import MapOfStringWrapper
from ntnx_security_py_client.models.common.v1.config.Message import Message
from ntnx_security_py_client.models.common.v1.config.MessageSeverity import MessageSeverity
from ntnx_security_py_client.models.common.v1.config.TenantAwareModel import TenantAwareModel
from ntnx_security_py_client.models.common.v1.response.ApiLink import ApiLink
from ntnx_security_py_client.models.common.v1.response.ApiResponseMetadata import ApiResponseMetadata
from ntnx_security_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel
from ntnx_security_py_client.models.iam.v4.authn.BucketsAccessKey import BucketsAccessKey
from ntnx_security_py_client.models.iam.v4.authn.BucketsAccessKeyStatusType import BucketsAccessKeyStatusType
from ntnx_security_py_client.models.iam.v4.authn.CreationType import CreationType
from ntnx_security_py_client.models.iam.v4.authn.User import User
from ntnx_security_py_client.models.iam.v4.authn.UserStatusType import UserStatusType
from ntnx_security_py_client.models.iam.v4.authn.UserType import UserType
from ntnx_security_py_client.models.prism.v4.config.TaskReference import TaskReference
from ntnx_security_py_client.models.security.v4.common.Cluster import Cluster
from ntnx_security_py_client.models.security.v4.common.ClusterProjection import ClusterProjection
from ntnx_security_py_client.models.security.v4.common.Timescale import Timescale
from ntnx_security_py_client.models.security.v4.config.AzureAccessInformation import AzureAccessInformation
from ntnx_security_py_client.models.security.v4.config.BasicAuthCredential import BasicAuthCredential
from ntnx_security_py_client.models.security.v4.config.BmcCredential import BmcCredential
from ntnx_security_py_client.models.security.v4.config.CreateCredentialApiResponse import CreateCredentialApiResponse
from ntnx_security_py_client.models.security.v4.config.CreateKeyManagementServerApiResponse import CreateKeyManagementServerApiResponse
from ntnx_security_py_client.models.security.v4.config.Credential import Credential
from ntnx_security_py_client.models.security.v4.config.DeleteCredentialApiResponse import DeleteCredentialApiResponse
from ntnx_security_py_client.models.security.v4.config.DeleteKeyManagementServerApiResponse import DeleteKeyManagementServerApiResponse
from ntnx_security_py_client.models.security.v4.config.ExternalSshAccessConfig import ExternalSshAccessConfig
from ntnx_security_py_client.models.security.v4.config.GetCredentialApiResponse import GetCredentialApiResponse
from ntnx_security_py_client.models.security.v4.config.GetKeyManagementServerApiResponse import GetKeyManagementServerApiResponse
from ntnx_security_py_client.models.security.v4.config.IntersightConnectionType import IntersightConnectionType
from ntnx_security_py_client.models.security.v4.config.IntersightCredential import IntersightCredential
from ntnx_security_py_client.models.security.v4.config.KeyBasedAuth import KeyBasedAuth
from ntnx_security_py_client.models.security.v4.config.KeyBasedAuthCredential import KeyBasedAuthCredential
from ntnx_security_py_client.models.security.v4.config.KeyManagementServer import KeyManagementServer
from ntnx_security_py_client.models.security.v4.config.ListCredentialsApiResponse import ListCredentialsApiResponse
from ntnx_security_py_client.models.security.v4.config.ListKeyManagementServersApiResponse import ListKeyManagementServersApiResponse
from ntnx_security_py_client.models.security.v4.config.PasswordStatus import PasswordStatus
from ntnx_security_py_client.models.security.v4.config.PasswordVerificationStatus import PasswordVerificationStatus
from ntnx_security_py_client.models.security.v4.config.ScheduleType import ScheduleType
from ntnx_security_py_client.models.security.v4.config.SecurityConfig import SecurityConfig
from ntnx_security_py_client.models.security.v4.config.SecurityConfigProjection import SecurityConfigProjection
from ntnx_security_py_client.models.security.v4.config.SecurityConfigVisibilitySetting import SecurityConfigVisibilitySetting
from ntnx_security_py_client.models.security.v4.config.UpdateCredentialApiResponse import UpdateCredentialApiResponse
from ntnx_security_py_client.models.security.v4.config.UpdateKeyManagementServerApiResponse import UpdateKeyManagementServerApiResponse
from ntnx_security_py_client.models.security.v4.config.VcenterCredential import VcenterCredential
from ntnx_security_py_client.models.security.v4.config.VerifyPassword import VerifyPassword
from ntnx_security_py_client.models.security.v4.config.VerifyPasswordSpec import VerifyPasswordSpec
from ntnx_security_py_client.models.security.v4.error.AppMessage import AppMessage
from ntnx_security_py_client.models.security.v4.error.ErrorResponse import ErrorResponse
from ntnx_security_py_client.models.security.v4.error.SchemaValidationError import SchemaValidationError
from ntnx_security_py_client.models.security.v4.error.SchemaValidationErrorMessage import SchemaValidationErrorMessage
from ntnx_security_py_client.models.security.v4.management.ApprovalPolicy import ApprovalPolicy
from ntnx_security_py_client.models.security.v4.management.ApproverGroup import ApproverGroup
from ntnx_security_py_client.models.security.v4.management.AssociatePoliciesApiResponse import AssociatePoliciesApiResponse
from ntnx_security_py_client.models.security.v4.management.AssociatePoliciesSpec import AssociatePoliciesSpec
from ntnx_security_py_client.models.security.v4.management.CreateApprovalPolicyApiResponse import CreateApprovalPolicyApiResponse
from ntnx_security_py_client.models.security.v4.management.EventType import EventType
from ntnx_security_py_client.models.security.v4.management.GetApprovalPolicyApiResponse import GetApprovalPolicyApiResponse
from ntnx_security_py_client.models.security.v4.management.ListApprovalPoliciesApiResponse import ListApprovalPoliciesApiResponse
from ntnx_security_py_client.models.security.v4.management.PolicyType import PolicyType
from ntnx_security_py_client.models.security.v4.management.SecuredEntityType import SecuredEntityType
from ntnx_security_py_client.models.security.v4.management.SecuredPolicy import SecuredPolicy
from ntnx_security_py_client.models.security.v4.management.SecurityValidationSpec import SecurityValidationSpec
from ntnx_security_py_client.models.security.v4.management.UpdateApprovalPolicyApiResponse import UpdateApprovalPolicyApiResponse
from ntnx_security_py_client.models.security.v4.report.IssueSummary import IssueSummary
from ntnx_security_py_client.models.security.v4.report.ListStigSummariesApiResponse import ListStigSummariesApiResponse
from ntnx_security_py_client.models.security.v4.report.ListStigsApiResponse import ListStigsApiResponse
from ntnx_security_py_client.models.security.v4.report.Severity import Severity
from ntnx_security_py_client.models.security.v4.report.SoftwareType import SoftwareType
from ntnx_security_py_client.models.security.v4.report.Stig import Stig
from ntnx_security_py_client.models.security.v4.report.StigProjection import StigProjection
from ntnx_security_py_client.models.security.v4.report.StigStatus import StigStatus
from ntnx_security_py_client.models.security.v4.report.StigSummary import StigSummary
from ntnx_security_py_client.models.security.v4.report.StigSummaryProjection import StigSummaryProjection
from ntnx_security_py_client.models.security.v4.report.Summary import Summary
from ntnx_security_py_client.models.security.v4.report.SummaryProjection import SummaryProjection
from ntnx_security_py_client.models.security.v4.report.TrendValue import TrendValue
from ntnx_security_py_client.models.security.v4.report.Vulnerability import Vulnerability
from ntnx_security_py_client.models.security.v4.report.VulnerabilityProjection import VulnerabilityProjection
from ntnx_security_py_client.models.security.v4.report.VulnerabilitySummary import VulnerabilitySummary
from ntnx_security_py_client.models.security.v4.report.VulnerabilitySummaryProjection import VulnerabilitySummaryProjection
